@@ -1,21 +1,26 @@
 from logging import getLogger
 
+from django.conf import settings
 from django.db import models
+from django.db.models import UniqueConstraint, Q
 from django.contrib.postgres import fields as psql_fields
 from django.contrib.postgres import search as psql_search
-from django.db.models import UniqueConstraint, Q
+from django_lifecycle import AFTER_UPDATE, BEFORE_UPDATE, hook
 
 from pulpcore.plugin.models import (
     BaseModel,
     Content,
     Remote,
     Repository,
+    RepositoryVersion,
     Distribution,
     SigningService,
     Task,
+    EncryptedTextField,
 )
 from .downloaders import AnsibleDownloaderFactory
 
+
 log = getLogger(__name__)
 
 
@@ -48,6 +53,10 @@ class Collection(BaseModel):
     namespace = models.CharField(max_length=64, editable=False)
     name = models.CharField(max_length=64, editable=False)
 
+    def __str__(self):
+        """Return a representation."""
+        return f"<{self.__class__.__name__}: {self.namespace}.{self.name}>"
+
     class Meta:
         unique_together = ("namespace", "name")
 
@@ -167,6 +176,10 @@ class CollectionVersion(Content):
             namespace=self.namespace, name=self.name, version=self.version
         )
 
+    def __str__(self):
+        """Return a representation."""
+        return f"<{self.__class__.__name__}: {self.namespace}.{self.name} {self.version}>"
+
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
         unique_together = ("namespace", "name", "version")
@@ -199,8 +212,8 @@ class CollectionVersionSignature(Content):
     signed_collection = models.ForeignKey(
         CollectionVersion, on_delete=models.CASCADE, related_name="signatures"
     )
-    data = models.BinaryField()  # This is what the pulp_container folks used
-    digest = models.CharField(max_length=64)  # does adding a min length improve db efficiency?
+    data = models.TextField()
+    digest = models.CharField(max_length=64)
     pubkey_fingerprint = models.CharField(max_length=64)
     signing_service = models.ForeignKey(
         SigningService, on_delete=models.SET_NULL, related_name="signatures", null=True
@@ -211,6 +224,31 @@ class CollectionVersionSignature(Content):
         unique_together = ("pubkey_fingerprint", "signed_collection")
 
 
+class DownloadLog(BaseModel):
+    """
+    A download log for content units by user, IP and org_id.
+    """
+
+    content_unit = models.ForeignKey(
+        Content, on_delete=models.CASCADE, related_name="download_logs"
+    )
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL,
+        on_delete=models.CASCADE,
+        null=True,
+        related_name="download_logs",
+    )
+    ip = models.GenericIPAddressField()
+    extra_data = models.JSONField(null=True)
+    user_agent = models.TextField()
+    repository = models.ForeignKey(
+        Repository, on_delete=models.CASCADE, related_name="download_logs"
+    )
+    repository_version = models.ForeignKey(
+        RepositoryVersion, null=True, on_delete=models.SET_NULL, related_name="download_logs"
+    )
+
+
 class RoleRemote(Remote):
     """
     A Remote for Ansible content.
@@ -231,7 +269,7 @@ class CollectionRemote(Remote):
 
     requirements_file = models.TextField(null=True)
     auth_url = models.CharField(null=True, max_length=255)
-    token = models.TextField(null=True, max_length=2000)
+    token = EncryptedTextField(null=True)
     sync_dependencies = models.BooleanField(default=True)
     signed_only = models.BooleanField(default=False)
 
@@ -256,6 +294,16 @@ class CollectionRemote(Remote):
             self._download_factory = AnsibleDownloaderFactory(self)
             return self._download_factory
 
+    @hook(
+        AFTER_UPDATE,
+        when_any=["url", "requirements_file", "sync_dependencies", "signed_only"],
+        has_changed=True,
+    )
+    def _reset_repository_last_synced_metadata_time(self):
+        AnsibleRepository.objects.filter(
+            remote_id=self.pk, last_synced_metadata_time__isnull=False
+        ).update(last_synced_metadata_time=None)
+
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
 
@@ -308,7 +356,7 @@ class AnsibleRepository(Repository):
     REMOTE_TYPES = [RoleRemote, CollectionRemote]
 
     last_synced_metadata_time = models.DateTimeField(null=True)
-    keyring = models.FilePathField(path="/etc/pulp/certs/", recursive=True, blank=True)
+    gpgkey = models.TextField(null=True)
 
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
@@ -347,6 +395,10 @@ class AnsibleRepository(Repository):
 
                 new_version.remove_content(deprecations)
 
+    @hook(BEFORE_UPDATE, when="remote", has_changed=True)
+    def _reset_repository_last_synced_metadata_time(self):
+        self.last_synced_metadata_time = None
+
 
 class AnsibleDistribution(Distribution):
     """
