@@ -49,6 +49,7 @@ from .serializers import (
     RoleRemoteSerializer,
     AnsibleRepositorySerializer,
     AnsibleRepositorySyncURLSerializer,
+    AnsibleRepositoryRebuildSerializer,
     AnsibleRepositorySignatureSerializer,
     CollectionSerializer,
     CollectionVersionSerializer,
@@ -60,7 +61,8 @@ from .serializers import (
     RoleSerializer,
     TagSerializer,
 )
-from .tasks.collections import update_collection_remote, sync as collection_sync
+from .tasks.collections import sync as collection_sync
+from .tasks.collections import rebuild_repository_collection_versions_metadata
 from .tasks.copy import copy_content
 from .tasks.roles import synchronize as role_sync
 from .tasks.git import synchronize as git_sync
@@ -327,6 +329,30 @@ class AnsibleRepositoryViewSet(RepositoryViewSet, ModifyRepositoryActionMixin):
         )
         return OperationPostponedResponse(result, request)
 
+    @extend_schema(
+        description="Trigger an asynchronous task to rebuild Ansible content meta.",
+        responses={202: AsyncOperationResponseSerializer},
+    )
+    @action(detail=True, methods=["post"], serializer_class=AnsibleRepositoryRebuildSerializer)
+    def rebuild_metadata(self, request, pk):
+        """
+        Dispatches a collection version rebuild task.
+        """
+        repository = self.get_object()
+        serializer = AnsibleRepositoryRebuildSerializer(
+            data=request.data, context={"request": request, "repository_pk": repository.pk}
+        )
+        serializer.is_valid(raise_exception=True)
+
+        result = dispatch(
+            rebuild_repository_collection_versions_metadata,
+            exclusive_resources=[],
+            shared_resources=[repository],
+            args=[repository.latest_version().pk],
+            kwargs=serializer.data,
+        )
+        return OperationPostponedResponse(result, request)
+
     @extend_schema(
         description="Trigger an asynchronous task to sign Ansible content.",
         responses={202: AsyncOperationResponseSerializer},
@@ -375,6 +401,31 @@ class AnsibleRepositoryVersionViewSet(RepositoryVersionViewSet):
 
     parent_viewset = AnsibleRepositoryViewSet
 
+    @extend_schema(
+        description="Trigger an asynchronous task to rebuild Ansible content meta.",
+        responses={202: AsyncOperationResponseSerializer},
+    )
+    @action(detail=True, methods=["post"], serializer_class=AnsibleRepositoryRebuildSerializer)
+    def rebuild_metadata(self, request, pk):
+        """
+        Dispatches a collection version rebuild task.
+        """
+        repository_version = self.get_object()
+        serializer = AnsibleRepositoryRebuildSerializer(
+            data=request.data,
+            context={"request": request, "repository_version_pk": repository_version.pk},
+        )
+        serializer.is_valid(raise_exception=True)
+
+        result = dispatch(
+            rebuild_repository_collection_versions_metadata,
+            exclusive_resources=[],
+            shared_resources=[repository_version.repository],
+            args=[repository_version.pk],
+            kwargs=serializer.data,
+        )
+        return OperationPostponedResponse(result, request)
+
 
 class CollectionRemoteViewSet(RemoteViewSet):
     """
@@ -385,25 +436,15 @@ class CollectionRemoteViewSet(RemoteViewSet):
     queryset = CollectionRemote.objects.all()
     serializer_class = CollectionRemoteSerializer
 
-    @extend_schema(
-        description="Trigger an asynchronous update task",
-        responses={202: AsyncOperationResponseSerializer},
-    )
-    def update(self, request, pk, **kwargs):
-        """Update remote."""
-        partial = kwargs.pop("partial", False)
-        lock = [self.get_object()]
+    def async_reserved_resources(self, instance):
+        if instance is None:
+            return []
+        lock = [instance]
         repos = AnsibleRepository.objects.filter(
-            remote_id=pk, last_synced_metadata_time__isnull=False
-        ).all()
-        lock.extend(repos)
-        async_result = dispatch(
-            update_collection_remote,
-            exclusive_resources=lock,
-            args=(pk,),
-            kwargs={"data": request.data, "partial": partial},
+            remote_id=instance.pk, last_synced_metadata_time__isnull=False
         )
-        return OperationPostponedResponse(async_result, request)
+        lock.extend(repos)
+        return lock
 
 
 class CollectionUploadViewSet(viewsets.ViewSet, UploadGalaxyCollectionMixin):
